@@ -81,13 +81,13 @@ PRO_TEAM_MAP = {
 
 ACTIVITY_MAP = {
     178: 'FA ADDED',
-    180: 'WAVIER ADDED',
+    180: 'WAIVER ADDED',
     179: 'DROPPED',
     181: 'DROPPED',
     239: 'DROPPED',
     244: 'TRADED',
     'FA': 178,
-    'WAVIER': 180,
+    'WAIVER': 180,
     'TRADED': 244
 }
 
